@@ -94,6 +94,7 @@ def csr_types(isa_yaml, work_dir,  bsv, logging=False):
     bsvfile.write('''
 package {0} ;
     `include "csrbox.defines"
+    `include "Logger.bsv"
 
 '''.format(pkg_name))
     if 'C' in isa_yaml['hart0']['ISA'] :
@@ -834,11 +835,13 @@ def station_req(isa_yaml, grp_yaml, attr_yaml, rvxlen, pkg_name,
         :type bsvstr: str
         :type work_dir: str
     '''
+    global debug_enabled
     global compressed_enabled
+    global supervisor_enabled
 
     if logging:
         logger.info('Generating Core request routine for : ' + pkg_name)
-    bsvstr += method_csr_req_def_temp
+    bsvstr += method_csr_req_def_temp.format(pkg_name)
     bsvstr += method_case_req
     xlen = int(rvxlen[2:])
 
@@ -870,17 +873,19 @@ def station_req(isa_yaml, grp_yaml, attr_yaml, rvxlen, pkg_name,
 
         if 'csr_op' in attr_yaml[csrname] and (\
                 shadow_csr is None or shadow_csr in isa_yaml):
-                if logging:
-                    logger.debug('-- Creating custom logic for : ' + csrname)
                 for csrop in attr_yaml[csrname]['csr_op']:
                     if '::' in csrop:
                         cond = csrop.split('::')[0]
                         if eval(cond):
                             cust_csrop = csrop.split('::')[1]
+                            if logging:
+                                logger.debug('-- Creating custom logic for : ' + csrname)
+                            break
                         else:
                             cust_csrop = ''
                     else:
                         cust_csrop = csrop
+                        break
                 _t = cust_csrop.replace('size',str(size))
                 _t = _t.replace('xlen',str(xlen))
                 _t = textwrap.indent(_t, '            ') + '\n'
@@ -897,7 +902,7 @@ def station_req(isa_yaml, grp_yaml, attr_yaml, rvxlen, pkg_name,
     if last:
         bsvstr += (endcase_temp)
     else:
-        bsvstr += (endcase_fwd_temp)
+        bsvstr += (endcase_fwd_temp.format(pkg_name))
     if logging:
         logger.info('Core request routine created for : ' + pkg_name)
 
